pub enum DownloadMode {
Diff,
Package,
File,
}Expand description
Selects which kind of patch artifact fetch_missing_sources downloads.
File— per-file blobs (legacy, largest, always applicable).Diff— per-patch tar.gz of bsdiff deltas (smallest, only useful when the original file is on disk).Package— per-patch tar.gz of patched files (mid-size, applicable even when the original file is missing).
Variants
Implementations