pub fn get_referenced_blobs(manifest: &PatchManifest) -> HashSet<String>Expand description
Get all blob hashes referenced by a manifest (both beforeHash and afterHash). Used for garbage collection and validation.
pub fn get_referenced_blobs(manifest: &PatchManifest) -> HashSet<String>Get all blob hashes referenced by a manifest (both beforeHash and afterHash). Used for garbage collection and validation.