Structs
- Postinstall
Status - Status of postinstall script configuration.
Functions
- generate_
updated_ postinstall - Generate an updated postinstall script that includes socket-patch.
- is_
postinstall_ configured - Check if a postinstall script is properly configured for socket-patch.
- is_
postinstall_ configured_ str - Check if a postinstall script string is configured for socket-patch.
- update_
package_ json_ content - Parse package.json content and update it with socket-patch postinstall. Returns (modified, new_content, old_script, new_script).
- update_
package_ json_ object - Update a package.json Value with the new postinstall script. Returns (modified, new_script).