Module patch

Module patch 

Modules

apply
apply_lock
Advisory file lock used to serialize mutating operations against a single .socket/ directory.
cow
Copy-on-write defense against package-manager hardlink farms.
diff
Per-file diff (bsdiff) apply support.
file_hash
package
Package- and diff-archive tarball helpers.
rollback
sidecars
Per-ecosystem fixups for the integrity sidecars that package managers verify at build/install time.