Skip to main content Module apply Copy item path Source ApplyResult Result of applying patches to a single package. PatchSources Patch sources the apply pipeline may use to obtain patched bytes. VerifyResult Result of verifying whether a single file can be patched. AppliedVia Which patch source actually wrote the patched bytes for a file. VerifyStatus Status of a file patch verification. apply_file_patch Apply a patch to a single file. apply_package_patch Verify and apply patches for a single package. normalize_file_path Normalize file path by removing the “package/” prefix if present.
Patch files come from the API with paths like “package/lib/file.js”
but we need relative paths like “lib/file.js” for the actual package directory. select_installed_variants Select the single variant whose installed bytes match the on-disk
distribution — i.e. the “minimally required” release for this
environment. verify_file_patch Verify a single file can be patched.