Module rollback

Module rollback 

Structs

RollbackResult
Result of rolling back patches for a single package.
VerifyRollbackResult
Result of verifying whether a single file can be rolled back.

Enums

VerifyRollbackStatus
Status of a file rollback verification.

Functions

rollback_file_patch
Rollback a single file to its original state by writing original_content (whose Git SHA256 must equal expected_hash).
rollback_package_patch
Verify and rollback patches for a single package.
verify_file_rollback
Verify a single file can be rolled back.