pub struct ApiClientOptions {
pub api_url: String,
pub api_token: Option<String>,
pub use_public_proxy: bool,
pub org_slug: Option<String>,
}Expand description
Options for constructing an ApiClient.
Fields
api_url: Stringapi_token: Option<String>use_public_proxy: boolWhen true, the client will use the public patch API proxy which only provides access to free patches without authentication.
org_slug: Option<String>Organization slug for authenticated API access. Required when using authenticated API (not public proxy).