Module detect

Module detect 

Structs

PostinstallStatus
Status of postinstall script configuration.

Functions

generate_updated_postinstall
Generate an updated postinstall script that includes socket-patch.
is_postinstall_configured
Check if a postinstall script is properly configured for socket-patch.
is_postinstall_configured_str
Check if a postinstall script string is configured for socket-patch.
update_package_json_content
Parse package.json content and update it with socket-patch postinstall. Returns (modified, new_content, old_script, new_script).
update_package_json_object
Update a package.json Value with the new postinstall script. Returns (modified, new_script).