Module apply
socket_
patch_
core
3.1.0
Module apply
Module Items
Structs
Enums
Functions
In socket_
patch_
core::
patch
socket_patch_core
::
patch
Module
apply
Structs

Apply
Result
Result of applying patches to a single package.
Patch
Sources
Patch sources the apply pipeline may use to obtain patched bytes.
Verify
Result
Result of verifying whether a single file can be patched.
Enums

Applied
Via
Which patch source actually wrote the patched bytes for a file.
Verify
Status
Status of a file patch verification.
Functions

apply_
file_
patch
Apply a patch to a single file.
apply_
package_
patch
Verify and apply patches for a single package.
normalize_
file_
path
Normalize file path by removing the “package/” prefix if present. Patch files come from the API with paths like “package/lib/file.js” but we need relative paths like “lib/file.js” for the actual package directory.
verify_
file_
patch
Verify a single file can be patched.