Module apply

Module apply 

Structs

ApplyResult
Result of applying patches to a single package.
VerifyResult
Result of verifying whether a single file can be patched.

Enums

VerifyStatus
Status of a file patch verification.

Functions

apply_file_patch
Apply a patch to a single file. Writes the patched content and verifies the resulting hash.
apply_package_patch
Verify and apply patches for a single package.
normalize_file_path
Normalize file path by removing the “package/” prefix if present. Patch files come from the API with paths like “package/lib/file.js” but we need relative paths like “lib/file.js” for the actual package directory.
verify_file_patch
Verify a single file can be patched.