pub fn apply_diff(before: &[u8], delta: &[u8]) -> Result<Vec<u8>, Error>Expand description
Apply a bsdiff delta to before and return the resulting bytes.
Returns an std::io::Error when the delta is malformed or applying it
fails (for example, the delta was produced from a different source).