Structs
- Rollback
Result - Result of rolling back patches for a single package.
- Verify
Rollback Result - Result of verifying whether a single file can be rolled back.
Enums
- Verify
Rollback Status - Status of a file rollback verification.
Functions
- rollback_
file_ patch - Rollback a single file to its original state. Writes the original content and verifies the resulting hash.
- rollback_
package_ patch - Verify and rollback patches for a single package.
- verify_
file_ rollback - Verify a single file can be rolled back.